from setuptools import setup, find_packages

setup(name='draw with percentage',
      version='0.0.4',
      description='Python Library to draw with percentage',
      author='Mateusz Kołodziejczyk',
      author_email='mateusz.j.kolodziejczyk@gmail.com',
      license='MIT',
      python_requires='>=3.5',
      packages=find_packages()
      )
